# Getting Started With Docker

## Clone Docker Cookbooks

[Github Docker Compose Cookbooks](https://github.com/nickyeoman/docker-compose-cookbooks)

```bash
git clone git@github.com:nickyeoman/docker-compose-cookbooks.git /docker-compose-cookbooks
```

## Setup Docker Compose File

Read the sample extends file of /docker-compose-cookbooks/phpcontainer/sample-extends.yml 

```bash
# ensure docker-compose exists
[[ -f docker-compose.yml ]] || echo "services:" > docker-compose.yml

# PHP container
tail -n+2 /docker-compose-cookbooks/phpcontainer/sample-extends.yml >> docker-compose.yml

# PHP settings
cp -r /docker-compose-cookbooks/phpcontainer/config .

# Set project directory
sed -i 's|- "./project:/data"|- "./:/data"|' docker-compose.yml

# Mariadb container
tail -n +2 /docker-compose-cookbooks/mariadb/sample-extends.yml >> docker-compose.yml

```

## ENV File

Then setup the .env file, which should look something like this:

```
COOKBOOK=/docker-compose-cookbooks
COMPOSE_PROJECT_NAME=myProject
TZ=America/Vancouver
VOL_CONFIG_PATH=/data/myProject/config
VOL_PATH=/data/myProject/data

# PHP Container
PHPCONTAINER_IMAGE=4lights/phpcontainer:latest

# MariaDB
MARIADB_IMAGE=mariadb:latest
MARIADB_MARIADB_DATABASE=mydb
MARIADB_MARIADB_ROOT_PASSWORD=ChangeThisPassword0123456789ABCD
MARIADB_MARIADB_PASSWORD=AlsoChangeThisPassword0123456789
MARIADB_MARIADB_USER=dbuser
```

## APP Database config

Open the /App/config.php file and change the database section to match the above:

```php
'database' => [ 
        'host' => 'mariadb',
        'name' => 'mydb',
        'user' => 'dbuser',
        'pass' => 'AlsoChangeThisPassword0123456789',
        'port' => 3306
    ],
```


## Start Docker

```docker compose up -d```
